@@ -13,7 +13,7 @@ import (
 	monitoringv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
-	v1 "k8s.io/api/rbac/v1"
+	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
@@ -137,7 +137,7 @@ func TestKnativeKafkaReconcile(t *testing.T) {
 				}
 
 				// Check if the clusterrolebinding for the Kafka deployment is created
-				crb := &v1.ClusterRoleBinding{}
+				crb := &rbacv1.ClusterRoleBinding{}
 				err = cl.Get(context.TODO(), types.NamespacedName{Name: fmt.Sprintf("rbac-proxy-reviews-prom-rb-%s", deployment.Name)}, crb)
 				if err != nil {
 					t.Fatalf("get: (%v)", err)
@@ -437,7 +437,7 @@ func makeCr(mods ...func(*v1alpha1.KnativeKafka)) *v1alpha1.KnativeKafka {
 				BootstrapServers: "foo.bar.com",
 			},
 			HighAvailability: &operatorv1alpha1.HighAvailability{
-				Replicas: 2,
+				Replicas: 1,
 			},
 		},
 	}
@@ -472,7 +472,7 @@ func TestCheckHAComponent(t *testing.T) {
 	}, {
 		name:           "kafka webhook",
 		deploymentName: "kafka-webhook",
-		shouldFail:     false,
+		shouldFail:     true,
 	}, {
 		name:           "kafka source controller",
 		deploymentName: "kafka-controller-manager",
