@@ -6,7 +6,7 @@ import (
 	"net/http"
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
-	eventingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
+	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/webhook/admission"
 )
 
@@ -15,13 +15,19 @@ type Configurator struct {
 	decoder *admission.Decoder
 }
 
+// NewConfigurator creates a new Configurator instance to configure KnativeEventing CRs.
+func NewConfigurator(decoder *admission.Decoder) *Configurator {
+	return &Configurator{
+		decoder: decoder,
+	}
+}
+
 // Implement admission.Handler so the controller can handle admission request.
 var _ admission.Handler = (*Configurator)(nil)
 
-// Configurator adds an annotation to every incoming
-// KnativeEventing CR.
+// Handle implements the Handler interface.
 func (v *Configurator) Handle(ctx context.Context, req admission.Request) admission.Response {
-	ke := &eventingv1alpha1.KnativeEventing{}
+	ke := &operatorv1alpha1.KnativeEventing{}
 
 	err := v.decoder.Decode(req, ke)
 	if err != nil {
@@ -36,13 +42,3 @@ func (v *Configurator) Handle(ctx context.Context, req admission.Request) admiss
 	}
 	return admission.PatchResponseFromRaw(req.AdmissionRequest.Object.Raw, marshaled)
 }
-
-// Configurator implements inject.Decoder.
-// A decoder will be automatically injected.
-var _ admission.DecoderInjector = (*Configurator)(nil)
-
-// InjectDecoder injects the decoder.
-func (v *Configurator) InjectDecoder(d *admission.Decoder) error {
-	v.decoder = d
-	return nil
-}
