@@ -6,69 +6,69 @@ import (
 	"testing"
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/apis"
-	operatorv1alpha1 "github.com/openshift-knative/serverless-operator/knative-operator/pkg/apis/operator/v1alpha1"
+	serverlessoperatorv1alpha1 "github.com/openshift-knative/serverless-operator/knative-operator/pkg/apis/operator/v1alpha1"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/webhook/testutil"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes/scheme"
-	eventingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
+	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	"sigs.k8s.io/controller-runtime/pkg/webhook/admission"
 )
 
 var (
-	defaultCR = &operatorv1alpha1.KnativeKafka{
+	defaultCR = &serverlessoperatorv1alpha1.KnativeKafka{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "defaultCR",
 			Namespace: "knative-eventing",
 		},
-		Spec: operatorv1alpha1.KnativeKafkaSpec{
-			Source: operatorv1alpha1.Source{
+		Spec: serverlessoperatorv1alpha1.KnativeKafkaSpec{
+			Source: serverlessoperatorv1alpha1.Source{
 				Enabled: false,
 			},
-			Channel: operatorv1alpha1.Channel{
+			Channel: serverlessoperatorv1alpha1.Channel{
 				Enabled: false,
 			},
 		},
 	}
-	duplicateCR = &operatorv1alpha1.KnativeKafka{
+	duplicateCR = &serverlessoperatorv1alpha1.KnativeKafka{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "duplicateCR",
 			Namespace: "knative-eventing",
 		},
-		Spec: operatorv1alpha1.KnativeKafkaSpec{
-			Source: operatorv1alpha1.Source{
+		Spec: serverlessoperatorv1alpha1.KnativeKafkaSpec{
+			Source: serverlessoperatorv1alpha1.Source{
 				Enabled: false,
 			},
-			Channel: operatorv1alpha1.Channel{
+			Channel: serverlessoperatorv1alpha1.Channel{
 				Enabled: false,
 			},
 		},
 	}
-	invalidNamespaceCR = &operatorv1alpha1.KnativeKafka{
+	invalidNamespaceCR = &serverlessoperatorv1alpha1.KnativeKafka{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "invalidNamespaceCR",
 			Namespace: "FOO",
 		},
-		Spec: operatorv1alpha1.KnativeKafkaSpec{
-			Source: operatorv1alpha1.Source{
+		Spec: serverlessoperatorv1alpha1.KnativeKafkaSpec{
+			Source: serverlessoperatorv1alpha1.Source{
 				Enabled: false,
 			},
-			Channel: operatorv1alpha1.Channel{
+			Channel: serverlessoperatorv1alpha1.Channel{
 				Enabled: false,
 			},
 		},
 	}
-	invalidShapeCRs = []operatorv1alpha1.KnativeKafka{
+	invalidShapeCRs = []serverlessoperatorv1alpha1.KnativeKafka{
 		{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "invalidShapeCR-1",
 				Namespace: "knative-eventing",
 			},
-			Spec: operatorv1alpha1.KnativeKafkaSpec{
-				Source: operatorv1alpha1.Source{
+			Spec: serverlessoperatorv1alpha1.KnativeKafkaSpec{
+				Source: serverlessoperatorv1alpha1.Source{
 					Enabled: false,
 				},
-				Channel: operatorv1alpha1.Channel{
+				Channel: serverlessoperatorv1alpha1.Channel{
 					Enabled: true,
 					// need to have bootstrapServers defined here!
 				},
@@ -79,11 +79,11 @@ var (
 				Name:      "invalidShapeCR-2",
 				Namespace: "knative-eventing",
 			},
-			Spec: operatorv1alpha1.KnativeKafkaSpec{
-				Source: operatorv1alpha1.Source{
+			Spec: serverlessoperatorv1alpha1.KnativeKafkaSpec{
+				Source: serverlessoperatorv1alpha1.Source{
 					Enabled: false,
 				},
-				Channel: operatorv1alpha1.Channel{
+				Channel: serverlessoperatorv1alpha1.Channel{
 					Enabled:             true,
 					BootstrapServers:    "foo.example.com",
 					AuthSecretNamespace: "my-ns",
@@ -96,11 +96,11 @@ var (
 				Name:      "invalidShapeCR-3",
 				Namespace: "knative-eventing",
 			},
-			Spec: operatorv1alpha1.KnativeKafkaSpec{
-				Source: operatorv1alpha1.Source{
+			Spec: serverlessoperatorv1alpha1.KnativeKafkaSpec{
+				Source: serverlessoperatorv1alpha1.Source{
 					Enabled: false,
 				},
-				Channel: operatorv1alpha1.Channel{
+				Channel: serverlessoperatorv1alpha1.Channel{
 					Enabled:          true,
 					BootstrapServers: "foo.example.com",
 					AuthSecretName:   "my-secret",
@@ -109,7 +109,7 @@ var (
 			},
 		},
 	}
-	validKnativeEventingCR = &eventingv1alpha1.KnativeEventing{
+	validKnativeEventingCR = &operatorv1alpha1.KnativeEventing{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "validKnativeEventing",
 			Namespace: "knative-eventing",
