@@ -6,7 +6,7 @@ import (
 	"net/http"
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
-	servingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
+	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/webhook/admission"
 )
@@ -28,10 +28,9 @@ func NewConfigurator(client client.Client, decoder *admission.Decoder) *Configur
 // Implement admission.Handler so the controller can handle admission request.
 var _ admission.Handler = (*Configurator)(nil)
 
-// Configurator adds an annotation to every incoming
-// KnativeServing CR.
+// Handle implements the Handler interface.
 func (v *Configurator) Handle(ctx context.Context, req admission.Request) admission.Response {
-	ks := &servingv1alpha1.KnativeServing{}
+	ks := &operatorv1alpha1.KnativeServing{}
 
 	err := v.decoder.Decode(req, ks)
 	if err != nil {
