@@ -5,46 +5,46 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 
-	"knative.dev/operator/pkg/apis/operator/v1alpha1"
+	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 )
 
 func TestConfigure(t *testing.T) {
 	cases := []struct {
 		name     string
-		in       v1alpha1.ConfigMapData
-		expected v1alpha1.ConfigMapData
+		in       operatorv1alpha1.ConfigMapData
+		expected operatorv1alpha1.ConfigMapData
 	}{{
 		name: "all nil",
-		expected: v1alpha1.ConfigMapData{
+		expected: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{
 				"bar": "baz",
 			},
 		},
 	}, {
 		name: "first level already set",
-		in: v1alpha1.ConfigMapData{
+		in: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{},
 		},
-		expected: v1alpha1.ConfigMapData{
+		expected: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{
 				"bar": "baz",
 			},
 		},
 	}, {
 		name: "override",
-		in: v1alpha1.ConfigMapData{
+		in: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{
 				"bar": "nope",
 			},
 		},
-		expected: v1alpha1.ConfigMapData{
+		expected: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{
 				"bar": "baz",
 			},
 		},
 	}, {
 		name: "unrelated values",
-		in: v1alpha1.ConfigMapData{
+		in: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{
 				"bar2": "baz2",
 			},
@@ -52,7 +52,7 @@ func TestConfigure(t *testing.T) {
 				"bar": "baz",
 			},
 		},
-		expected: v1alpha1.ConfigMapData{
+		expected: operatorv1alpha1.ConfigMapData{
 			"foo": map[string]string{
 				"bar":  "baz",
 				"bar2": "baz2",
@@ -65,7 +65,7 @@ func TestConfigure(t *testing.T) {
 
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
-			s := &v1alpha1.CommonSpec{Config: c.in}
+			s := &operatorv1alpha1.CommonSpec{Config: c.in}
 			Configure(s, "foo", "bar", "baz")
 
 			if !cmp.Equal(s.Config, c.expected) {
