@@ -4,32 +4,32 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
-	"knative.dev/operator/pkg/apis/operator/v1alpha1"
+	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 )
 
 func TestDefaultIngressClass(t *testing.T) {
 	cases := []struct {
 		name     string
-		in       *v1alpha1.KnativeServing
+		in       *operatorv1alpha1.KnativeServing
 		expected string
 	}{{
 		name:     "unset",
-		in:       &v1alpha1.KnativeServing{},
+		in:       &operatorv1alpha1.KnativeServing{},
 		expected: kourierIngressClassName,
 	}, {
 		name: "all disabled",
-		in: &v1alpha1.KnativeServing{
-			Spec: v1alpha1.KnativeServingSpec{
-				Ingress: &v1alpha1.IngressConfigs{},
+		in: &operatorv1alpha1.KnativeServing{
+			Spec: operatorv1alpha1.KnativeServingSpec{
+				Ingress: &operatorv1alpha1.IngressConfigs{},
 			},
 		},
 		expected: kourierIngressClassName,
 	}, {
 		name: "istio enabled",
-		in: &v1alpha1.KnativeServing{
-			Spec: v1alpha1.KnativeServingSpec{
-				Ingress: &v1alpha1.IngressConfigs{
-					Istio: v1alpha1.IstioIngressConfiguration{
+		in: &operatorv1alpha1.KnativeServing{
+			Spec: operatorv1alpha1.KnativeServingSpec{
+				Ingress: &operatorv1alpha1.IngressConfigs{
+					Istio: operatorv1alpha1.IstioIngressConfiguration{
 						Enabled: true,
 					},
 				},
@@ -38,13 +38,13 @@ func TestDefaultIngressClass(t *testing.T) {
 		expected: istioIngressClassName,
 	}, {
 		name: "kourier and istio enabled",
-		in: &v1alpha1.KnativeServing{
-			Spec: v1alpha1.KnativeServingSpec{
-				Ingress: &v1alpha1.IngressConfigs{
-					Kourier: v1alpha1.KourierIngressConfiguration{
+		in: &operatorv1alpha1.KnativeServing{
+			Spec: operatorv1alpha1.KnativeServingSpec{
+				Ingress: &operatorv1alpha1.IngressConfigs{
+					Kourier: operatorv1alpha1.KourierIngressConfiguration{
 						Enabled: true,
 					},
-					Istio: v1alpha1.IstioIngressConfiguration{
+					Istio: operatorv1alpha1.IstioIngressConfiguration{
 						Enabled: true,
 					},
 				},
