@@ -12,10 +12,10 @@ import (
 	"encoding/json"
 	"encoding/pem"
 	"fmt"
-	"io/ioutil"
 	"math/big"
 	"net"
 	"net/http"
+	"net/url"
 	"strings"
 	"testing"
 	"time"
@@ -25,8 +25,8 @@ import (
 
 	"github.com/openshift-knative/serverless-operator/test"
 	routev1 "github.com/openshift/api/route/v1"
-	core "k8s.io/api/core/v1"
-	meta "k8s.io/apimachinery/pkg/apis/meta/v1"
+	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -36,6 +36,7 @@ import (
 	"knative.dev/pkg/test/spoof"
 	"knative.dev/serving/pkg/apis/serving"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
+	servingTest "knative.dev/serving/test"
 )
 
 type testCase struct {
@@ -56,7 +57,7 @@ func isServiceMeshInstalled(ctx *test.Context) bool {
 		Group:    "apiextensions.k8s.io",
 		Version:  "v1",
 		Resource: "customresourcedefinitions",
-	}).Get(context.Background(), "servicemeshcontrolplanes.maistra.io", meta.GetOptions{})
+	}).Get(context.Background(), "servicemeshcontrolplanes.maistra.io", metav1.GetOptions{})
 
 	if err == nil {
 		return true
@@ -128,25 +129,25 @@ func setupCustomDomainTLSSecret(ctx *test.Context, serviceMeshNamespace, customS
 		Bytes: x509.MarshalPKCS1PrivateKey(customPrivateKey),
 	})
 
-	customSecret := &core.Secret{
-		ObjectMeta: meta.ObjectMeta{
+	customSecret := &corev1.Secret{
+		ObjectMeta: metav1.ObjectMeta{
 			Name:      customSecretName,
 			Namespace: serviceMeshNamespace,
 		},
-		Type: core.SecretTypeTLS,
+		Type: corev1.SecretTypeTLS,
 		Data: map[string][]byte{
-			core.TLSCertKey:       customPem,
-			core.TLSPrivateKeyKey: customPrivateKeyPem,
+			corev1.TLSCertKey:       customPem,
+			corev1.TLSPrivateKeyKey: customPrivateKeyPem,
 		},
 	}
 
-	customSecret, err = ctx.Clients.Kube.CoreV1().Secrets(customSecret.Namespace).Create(context.Background(), customSecret, meta.CreateOptions{})
+	customSecret, err = ctx.Clients.Kube.CoreV1().Secrets(customSecret.Namespace).Create(context.Background(), customSecret, metav1.CreateOptions{})
 	if err != nil {
 		ctx.T.Fatalf("Error creating Secret %q: %v", customSecretName, err)
 	}
 	ctx.AddToCleanup(func() error {
 		ctx.T.Logf("Cleaning up Secret %s", customSecret.GetName())
-		return ctx.Clients.Kube.CoreV1().Secrets(customSecret.Namespace).Delete(context.Background(), customSecret.Name, meta.DeleteOptions{})
+		return ctx.Clients.Kube.CoreV1().Secrets(customSecret.Namespace).Delete(context.Background(), customSecret.Name, metav1.DeleteOptions{})
 	})
 
 	// Return a CertPool with our example CA
@@ -224,7 +225,7 @@ func runTestForAllServiceMeshVersions(t *testing.T, testFunc func(ctx *test.Cont
 // A knative service acting as an "http proxy", redirects requests towards a given "host". Used to test cluster-local services
 func httpProxyService(name, namespace, host string) *servingv1.Service {
 	proxy := test.Service(name, namespace, httpProxyImage, nil)
-	proxy.Spec.Template.Spec.Containers[0].Env = append(proxy.Spec.Template.Spec.Containers[0].Env, core.EnvVar{
+	proxy.Spec.Template.Spec.Containers[0].Env = append(proxy.Spec.Template.Spec.Containers[0].Env, corev1.EnvVar{
 		Name:  "TARGET_HOST",
 		Value: host,
 	})
@@ -315,7 +316,7 @@ func rsaPublicKeyAsJwks(key rsa.PublicKey, keyID string) (string, error) {
 
 	jwksBytes, err := json.Marshal(jwks)
 	if err != nil {
-		return "", fmt.Errorf("error marshalling jwks: %v", err)
+		return "", fmt.Errorf("error marshalling jwks: %w", err)
 	}
 
 	return string(jwksBytes), nil
@@ -329,12 +330,12 @@ func jwtRs256Token(rsaKey *rsa.PrivateKey, payload map[string]interface{}) (stri
 	}
 	jwtHeaderBytes, err := json.Marshal(jwtHeader)
 	if err != nil {
-		return "", fmt.Errorf("error marshalling jwt header into JSON: %v", err)
+		return "", fmt.Errorf("error marshalling jwt header into JSON: %w", err)
 	}
 
 	jwtPayloadBytes, err := json.Marshal(payload)
 	if err != nil {
-		return "", fmt.Errorf("error marshalling jwt payload into JSON: %v", err)
+		return "", fmt.Errorf("error marshalling jwt payload into JSON: %w", err)
 	}
 
 	jwtHeaderBase64 := base64.RawURLEncoding.EncodeToString(jwtHeaderBytes)
@@ -347,7 +348,7 @@ func jwtRs256Token(rsaKey *rsa.PrivateKey, payload map[string]interface{}) (stri
 
 	signature, err := rsa.SignPKCS1v15(rand.Reader, rsaKey, crypto.SHA256, hash)
 	if err != nil {
-		return "", fmt.Errorf("error signing JWT token with PKSC1v15: %v", err)
+		return "", fmt.Errorf("error signing JWT token with PKSC1v15: %w", err)
 	}
 
 	jwtSignatureBase64 := base64.RawURLEncoding.EncodeToString(signature)
@@ -363,12 +364,12 @@ func jwtUnsignedToken(payload map[string]interface{}) (string, error) {
 	}
 	jwtHeaderBytes, err := json.Marshal(jwtHeader)
 	if err != nil {
-		return "", fmt.Errorf("error marshalling jwt header into JSON: %v", err)
+		return "", fmt.Errorf("error marshalling jwt header into JSON: %w", err)
 	}
 
 	jwtPayloadBytes, err := json.Marshal(payload)
 	if err != nil {
-		return "", fmt.Errorf("error marshalling jwt payload into JSON: %v", err)
+		return "", fmt.Errorf("error marshalling jwt payload into JSON: %w", err)
 	}
 
 	jwtHeaderBase64 := base64.RawURLEncoding.EncodeToString(jwtHeaderBytes)
@@ -381,22 +382,30 @@ func jwtUnsignedToken(payload map[string]interface{}) (string, error) {
 
 // Convenience method to test requests with tokens, reads the response and returns a closed response and the body bits
 // token can be nil, in which case no Authorization header will be sent
-func jwtHTTPGetRequestBytes(url string, token *string) (*http.Response, []byte, error) {
-	req, err := http.NewRequest("GET", url, nil)
+func jwtHTTPGetRequestBytes(ctx *test.Context, url *url.URL, token *string) (*spoof.Response, error) {
+	tlsConfig := servingTest.TLSClientConfig(context.Background(), ctx.T.Logf, &servingTest.Clients{KubeClient: ctx.Clients.Kube})
+	transport := &http.Transport{TLSClientConfig: tlsConfig}
+
+	sc := &spoof.SpoofingClient{
+		Client: &http.Client{Transport: transport},
+		Logf:   ctx.T.Logf,
+	}
+
+	req, err := http.NewRequest("GET", url.String(), nil)
 	if err != nil {
-		return nil, nil, fmt.Errorf("error creating HTTP GET request: %v", err)
+		return nil, fmt.Errorf("error creating HTTP GET request: %w", err)
 	}
 	if token != nil {
 		req.Header.Add("Authorization", "Bearer "+*token)
 	}
 
-	resp, err := http.DefaultClient.Do(req)
+	// Poll, as it is expected OpenShift Router will return 503s until it reconciles the Route.
+	resp, err := sc.Poll(req, spoof.IsOneOfStatusCodes(http.StatusOK, http.StatusUnauthorized, http.StatusForbidden))
 	if err != nil {
-		return nil, nil, fmt.Errorf("error doing HTTP GET request: %v", err)
+		return nil, fmt.Errorf("error polling: %w", err)
 	}
-	defer resp.Body.Close()
-	body, err := ioutil.ReadAll(resp.Body)
-	return resp, body, err
+
+	return resp, err
 }
 
 // Verifies access to a Ksvc with an istio-proxy can be configured
@@ -446,7 +455,7 @@ func TestKsvcWithServiceMeshJWTDefaultPolicy(t *testing.T) {
 		// Rerunning this test would fail if we kept the jwksUri constant across invocations then,
 		// hence the random suffix for the jwks ksvc.
 		jwksKsvc := test.Service(helpers.AppendRandomString("jwks"), testNamespace, "registry.ci.openshift.org/openshift/hello-openshift", nil)
-		jwksKsvc.Spec.Template.Spec.Containers[0].Env = append(jwksKsvc.Spec.Template.Spec.Containers[0].Env, core.EnvVar{
+		jwksKsvc.Spec.Template.Spec.Containers[0].Env = append(jwksKsvc.Spec.Template.Spec.Containers[0].Env, corev1.EnvVar{
 			Name:  "RESPONSE",
 			Value: jwks,
 		})
@@ -616,7 +625,9 @@ func TestKsvcWithServiceMeshJWTDefaultPolicy(t *testing.T) {
 				return true, nil
 			},
 			"WaitForRouteToServe401Or403",
-			true); err != nil {
+			true,
+			servingTest.AddRootCAtoTransport(context.Background(), t.Logf, &servingTest.Clients{KubeClient: ctx.Clients.Kube}, true),
+		); err != nil {
 			t.Fatalf("The Route at domain %s didn't serve the expected HTTP 401 or 403 status: %v", testKsvc.Status.URL.URL(), err)
 		}
 
@@ -721,20 +732,20 @@ func TestKsvcWithServiceMeshJWTDefaultPolicy(t *testing.T) {
 				}
 
 				// Do a request, optionally with a token
-				resp, body, err := jwtHTTPGetRequestBytes(testKsvc.Status.URL.String(), tokenRef)
+				resp, err := jwtHTTPGetRequestBytes(ctx, testKsvc.Status.URL.URL(), tokenRef)
 				if err != nil {
 					t.Fatalf("Error doing HTTP GET request: %v", err)
 				}
 
 				if scenario.valid {
 					// Verify the response is a proper "hello world" when the token is valid
-					if resp.StatusCode != 200 || !strings.Contains(string(body), helloworldText) {
-						t.Fatalf("Unexpected response with a valid token: HTTP %d: %s", resp.StatusCode, string(body))
+					if resp.StatusCode != 200 || !strings.Contains(string(resp.Body), helloworldText) {
+						t.Fatalf("Unexpected response with a valid token: HTTP %d: %s", resp.StatusCode, string(resp.Body))
 					}
 				} else {
 					// Verify the response is a 401 or a 403 for an invalid token
 					if resp.StatusCode != 401 && resp.StatusCode != 403 {
-						t.Fatalf("Unexpected response with an invalid token, expecting 401 or 403, got %d: %s", resp.StatusCode, string(body))
+						t.Fatalf("Unexpected response with an invalid token, expecting 401 or 403, got %d: %s", resp.StatusCode, string(resp.Body))
 					}
 				}
 			})
@@ -787,7 +798,7 @@ func TestKsvcWithServiceMeshCustomDomain(t *testing.T) {
 		// Create the OpenShift Route for the custom domain pointing to the istio-ingressgateway
 		// Note, this one is created in the service mesh namespace ("istio-system"), not the test namespace
 		route := &routev1.Route{
-			ObjectMeta: meta.ObjectMeta{
+			ObjectMeta: metav1.ObjectMeta{
 				Name:      "hello",
 				Namespace: serviceMeshTestNamespaceName,
 			},
@@ -802,14 +813,14 @@ func TestKsvcWithServiceMeshCustomDomain(t *testing.T) {
 				},
 			},
 		}
-		route, err := ctx.Clients.Route.Routes(serviceMeshTestNamespaceName).Create(context.Background(), route, meta.CreateOptions{})
+		route, err := ctx.Clients.Route.Routes(serviceMeshTestNamespaceName).Create(context.Background(), route, metav1.CreateOptions{})
 		if err != nil {
 			t.Fatalf("Error creating OpenShift Route: %v", err)
 		}
 
 		ctx.AddToCleanup(func() error {
 			t.Logf("Cleaning up OpenShift Route %s", route.GetName())
-			return ctx.Clients.Route.Routes(route.Namespace).Delete(context.Background(), route.Name, meta.DeleteOptions{})
+			return ctx.Clients.Route.Routes(route.Namespace).Delete(context.Background(), route.Name, metav1.DeleteOptions{})
 		})
 
 		// Do a spoofed HTTP request via the OpenShiftRouter
@@ -942,7 +953,7 @@ func TestKsvcWithServiceMeshCustomTlsDomain(t *testing.T) {
 		// Create the OpenShift Route for the custom domain pointing to the istio-ingressgateway
 		// Note, this one is created in the service mesh namespace ("istio-system"), not the test namespace
 		route := &routev1.Route{
-			ObjectMeta: meta.ObjectMeta{
+			ObjectMeta: metav1.ObjectMeta{
 				Name:      "hello",
 				Namespace: serviceMeshTestNamespaceName,
 			},
@@ -961,14 +972,14 @@ func TestKsvcWithServiceMeshCustomTlsDomain(t *testing.T) {
 				},
 			},
 		}
-		route, err := ctx.Clients.Route.Routes(serviceMeshTestNamespaceName).Create(context.Background(), route, meta.CreateOptions{})
+		route, err := ctx.Clients.Route.Routes(serviceMeshTestNamespaceName).Create(context.Background(), route, metav1.CreateOptions{})
 		if err != nil {
 			t.Fatalf("Error creating OpenShift Route: %v", err)
 		}
 
 		ctx.AddToCleanup(func() error {
 			t.Logf("Cleaning up OpenShift Route %s", route.GetName())
-			return ctx.Clients.Route.Routes(route.Namespace).Delete(context.Background(), route.Name, meta.DeleteOptions{})
+			return ctx.Clients.Route.Routes(route.Namespace).Delete(context.Background(), route.Name, metav1.DeleteOptions{})
 		})
 
 		// Do a spoofed HTTP request.
